@@ -14,10 +14,10 @@
 
     You should have received a copy of the GNU Lesser General Public
     License along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA
 
 		Project page: http://repo.hu/projects/scconfig
-		Contact via email: scconfig [at] igor2.repo.hu
+		Contact (email and IRC): http://igor2.repo.hu/contact.html
 */
 
 #include "dep.h"
@@ -60,6 +60,8 @@ void deps_default_init(void)
 	dep_add("cc/argmachine/*",          find_cc_argmachine);
 	dep_add("cc/pragma_message/*",      find_cc_pragma_message);
 	dep_add("cc/static_libgcc/*",       find_cc_static_libgcc);
+	dep_add("cc/default_c23",           find_cc_is_c23);
+	dep_add("cc/disable_c23/*",         find_cc_disable_c23);
 
 	dep_add("libs/ldl",                 find_lib_ldl);
 	dep_add("libs/LoadLibrary/*",       find_lib_LoadLibrary);
