@@ -15,10 +15,10 @@
 
     You should have received a copy of the GNU Lesser General Public
     License along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA
 
 		Project page: http://repo.hu/projects/scconfig
-		Contact via email: scconfig [at] igor2.repo.hu
+		Contact (email and IRC): http://igor2.repo.hu/contact.html
 */
 #include <stdlib.h>
 #include <string.h>
@@ -27,8 +27,9 @@
 #include "log.h"
 #include "db.h"
 #include "dep.h"
+#include "find_gl.h"
 
-int find_gl(const char *name, int logdepth, int fatal, const char *call, const char *arg)
+int find_gl(const char *name, int logdepth, int fatal)
 {
 	char test_c[256];
 	const char *test_c_templ =
@@ -48,8 +49,6 @@ int find_gl(const char *name, int logdepth, int fatal, const char *call, const c
 	const char **lf, *ldflgs[] = {"-lGL", "-lopengl32", "-framework OpenGL", NULL};
 	char *cflags = NULL;
 	char *ldflags = NULL;
-	(void) call;  /* not used */
-	(void) arg;  /* not used */
 
 	if (require("cc/cc", logdepth, fatal))
 		return try_fail(logdepth, node);
@@ -93,20 +92,21 @@ int find_gl(const char *name, int logdepth, int fatal, const char *call, const c
 	return 0;
 }
 
-int find_gl_vao(const char *name, int logdepth, int fatal, const char *call, const char *arg)
+int find_gl_vao(const char *name, int logdepth, int fatal)
 {
-	const char *test_c =
+	const char *test_c_templ =
 		NL "#include <stdio.h>"
+		NL "#include <%s/gl.h>"
 		NL "int main()"
 		NL "{"
 		NL "	glBindVertexArray(0);"
 		NL "	return 0;"
 		NL "}"
 		NL;
+	const char *incs_templ = "#define GL_GLEXT_PROTOTYPES\n%s\n#include <%s/gl.h>\n#include <%s/glext.h>";
+	char test_c[512], incs2[512];
 	const char *node = "libs/gui/gl/vao";
-	const char *cflags, *ldflags, *incs;
-	(void) call;  /* not used */
-	(void) arg;  /* not used */
+	const char *cflags, *ldflags, *incs, *ip;
 
 	if (require("cc/cc", logdepth, fatal))
 		return try_fail(logdepth, node);
@@ -117,18 +117,28 @@ int find_gl_vao(const char *name, int logdepth, int fatal, const char *call, con
 	cflags = get("libs/gui/gl/cflags");
 	ldflags = get("libs/gui/gl/ldflags");
 	incs = get("libs/gui/gl/includes");
+	ip = get("libs/gui/gl/include_prefix");
 
 	report("Checking for gl vao... ");
 	logprintf(logdepth, "find_gl_vao...\n");
 	logdepth++;
 
+	sprintf(test_c, test_c_templ, ip);
+	logprintf(logdepth, "trying vao with includes '%s'\n", incs);
 	if (try_icl_norun(logdepth, node, test_c, incs, cflags, ldflags) != 0)
 		return 0;
 
+	if (strlen(ip) + strlen(incs)+ strlen(incs_templ) + 8 < sizeof(incs2)) {
+		sprintf(incs2, incs_templ, incs, ip, ip);
+		logprintf(logdepth, "trying vao with includes2 '%s'\n", incs2);
+		if (try_icl_norun(logdepth, node, test_c, incs2, cflags, ldflags) != 0)
+			return 0;
+	}
+
 	return try_fail(logdepth, node);
 }
 
-int find_gl_fb_attachment(const char *name, int logdepth, int fatal, const char *call, const char *arg)
+int find_gl_fb_attachment(const char *name, int logdepth, int fatal)
 {
 	const char *test_c_templ =
 		NL "#include <stdio.h>"
@@ -140,11 +150,10 @@ int find_gl_fb_attachment(const char *name, int logdepth, int fatal, const char
 		NL "	return 0;"
 		NL "}"
 		NL;
-	char test_c[512];
+	const char *incs_templ = "#define GL_GLEXT_PROTOTYPES\n%s\n#include <%s/gl.h>\n#include <%s/glext.h>";
+	char test_c[512], incs2[512];
 	const char *node = "libs/gui/gl/fb_attachment";
 	const char *cflags, *ldflags, *incs, *ip;
-	(void) call;  /* not used */
-	(void) arg;  /* not used */
 
 	if (require("cc/cc", logdepth, fatal))
 		return try_fail(logdepth, node);
@@ -162,15 +171,22 @@ int find_gl_fb_attachment(const char *name, int logdepth, int fatal, const char
 	logdepth++;
 
 	sprintf(test_c, test_c_templ, ip);
-
+	logprintf(logdepth, "trying fb_att* with includes '%s'\n", incs);
 	if (try_icl_norun(logdepth, node, test_c, incs, cflags, ldflags) != 0)
 		return 0;
 
+	if (strlen(ip) + strlen(incs)+ strlen(incs_templ) + 8 < sizeof(incs2)) {
+		sprintf(incs2, incs_templ, incs, ip, ip);
+		logprintf(logdepth, "trying fb_att* with includes2 '%s'\n", incs2);
+		if (try_icl_norun(logdepth, node, test_c, incs2, cflags, ldflags) != 0)
+			return 0;
+	}
+
 	return try_fail(logdepth, node);
 }
 
 
-int find_glu(const char *name, int logdepth, int fatal, const char *call, const char *arg)
+int find_glu(const char *name, int logdepth, int fatal)
 {
 	char test_c[256];
 	const char *test_c_templ =
@@ -189,8 +205,6 @@ int find_glu(const char *name, int logdepth, int fatal, const char *call, const
 	char **cf, *cflgs[] = {"", "-I/usr/include/libdrm", NULL};
 	char *cflags = NULL;
 	char *ldflags = NULL;
-	(void) call;  /* not used */
-	(void) arg;  /* not used */
 
 	if (require("cc/cc", logdepth, fatal))
 		return try_fail(logdepth, node);
@@ -239,7 +253,7 @@ int find_glu(const char *name, int logdepth, int fatal, const char *call, const
 	return 0;
 }
 
-int find_glut(const char *name, int logdepth, int fatal, const char *call, const char *arg)
+int find_glut(const char *name, int logdepth, int fatal)
 {
 	const char *test_c =
 		NL "#include <stdio.h>"
@@ -256,8 +270,6 @@ int find_glut(const char *name, int logdepth, int fatal, const char *call, const
 	char **inc, *incs[] = {"", "#include <openglut.h>", NULL};
 	char *cflags = NULL;
 	char *ldflags = NULL;
-	(void) call;  /* not used */
-	(void) arg;  /* not used */
 
 	incs[0] = freeglut;
 
@@ -342,3 +354,91 @@ int find_gui_wgl(const char *name, int logdepth, int fatal)
 	if (try_icl(logdepth, node, test_c, "#include <wingdi.h>", NULL, "-lopengl32")) return 0;
 	return try_fail(logdepth, node);
 }
+
+static int accept_glfw(char *stdout_str)
+{
+	int major = 0, minor = 0, rev = 0;
+	char tmp[32];
+
+	if ((stdout_str[0] != 'O') || (stdout_str[1] != 'K'))
+		return 0;
+
+	sscanf(stdout_str + 2, "%d %d %d", &major, &minor, &rev);
+	sprintf(tmp, "%d", major); put("libs/gui/glfw/ver/major", tmp);
+	sprintf(tmp, "%d", minor); put("libs/gui/glfw/ver/minor", tmp);
+	sprintf(tmp, "%d", rev);   put("libs/gui/glfw/ver/rev", tmp);
+
+	return 1;
+}
+
+int find_glfw(const char *name, int logdepth, int fatal)
+{
+	const char *test_c =
+		NL "#include <stdio.h>"
+		NL "int main()"
+		NL "{"
+		NL "	int major = 0, minor = 0, rev = 0;"
+		NL "	glfwGetVersion(&major, &minor, &rev);"
+		NL "	if (major > 0)"
+		NL "		printf(\"OK %d %d %d\\n\", major, minor, rev);"
+		NL "	return 0;"
+		NL "}"
+		NL;
+	const char *node = "libs/gui/glfw", *ipr;
+	char freeglfw[4096];
+	char **inc, *incs[] = {"", "#include <GLFW/glfw3.h>", NULL};
+	char *cflags = NULL;
+	char *ldflags = NULL;
+
+	incs[0] = freeglfw;
+	freeglfw[0] = 0;
+
+	if (require("cc/cc", logdepth, fatal))
+		return try_fail(logdepth, node);
+
+
+	report("Checking for glfw... ");
+	logprintf(logdepth, "find_glfw: running pkg-config...\n");
+	logdepth++;
+
+	if (run_pkg_config(logdepth, "glfw3", &cflags, &ldflags) == 0) {
+		if (try_icl_(logdepth, node, test_c, incs[1], cflags, ldflags, 1, accept_glfw) != 0)
+			goto success;
+	}
+
+	if (require("libs/gui/gl/include_prefix", logdepth, fatal))
+		return try_fail(logdepth, node);
+	ipr = get("libs/gui/gl/include_prefix");
+	if (ipr == NULL)
+		return try_fail(logdepth, node);
+
+	if (cflags != NULL) {
+		free(cflags);
+		cflags = NULL;
+	}
+
+	if (ldflags != NULL) {
+		free(ldflags);
+		ldflags = NULL;
+	}
+
+	logdepth--;
+	logprintf(logdepth, "find_glfw: manual tries...\n");
+	logdepth++;
+
+	sprintf(freeglfw, "#include <%s/glfw.h>", ipr);
+	ldflags = strclone("-lglfw");
+	for(inc = incs; *inc != NULL; inc++)
+		if (try_icl_(logdepth, node, test_c, *inc, NULL, ldflags, 1, accept_glfw) != 0)
+			goto success;
+	free(ldflags);
+
+	return try_fail(logdepth, node);
+
+	success:;
+	if (cflags != NULL)
+		free(cflags);
+	if (ldflags != NULL)
+		free(ldflags);
+	return 0;
+}
