@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU Lesser General Public
     License along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA
 
 		Project page: http://repo.hu/projects/scconfig
 		Contact (email and IRC): http://igor2.repo.hu/contact.html
