@@ -1,4 +1,4 @@
 #include <librnd/core/compat_inc.h>
-DIR *rnd_opendir(rnd_hidlib_t *hidlib, const char *name);
+DIR *rnd_opendir(rnd_design_t *design, const char *name);
 struct dirent *rnd_readdir(DIR *dir);
 int rnd_closedir(DIR *dir);
