@@ -5,7 +5,7 @@
  *  (this file is based on PCB, interactive printed circuit board design)
  *  Copyright (C) 1994,1995,1996 Thomas Nau
  *  Copyright (C) 2004 harry eaton
- *  Copyright (C) 2016..2019 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2016..2019,2025 Tibor 'Igor2' Palinkas
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *  Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA.
  *
  *  Contact:
  *    Project page: http://www.repo.hu/projects/librnd
@@ -103,6 +103,25 @@ static void opt2attr(rnd_hid_attr_val_t *dst, const rnd_export_opt_t *src)
 	}
 }
 
+static void free_opt2attr(rnd_hid_attr_val_t *dst, const rnd_export_opt_t *src)
+{
+	switch(src->type) {
+		case RND_HATT_STRING:
+			free((char *)dst->str);
+			dst->str = NULL;
+			break;
+		case RND_HATT_LABEL:
+		case RND_HATT_INTEGER:
+		case RND_HATT_COORD:
+		case RND_HATT_BOOL:
+		case RND_HATT_REAL:
+		case RND_HATT_ENUM:
+		case RND_HATT_UNIT:
+		default:
+			break;
+	}
+}
+
 void rnd_hid_load_defaults(rnd_hid_t *hid, const rnd_export_opt_t *opts, int len)
 {
 	int n;
@@ -112,6 +131,15 @@ void rnd_hid_load_defaults(rnd_hid_t *hid, const rnd_export_opt_t *opts, int len
 		opt2attr(&values[n], opts + n);
 }
 
+void rnd_hid_free_defaults(rnd_hid_t *hid, const rnd_export_opt_t *opts, int len)
+{
+	int n;
+	rnd_hid_attr_val_t *values = hid->argument_array;
+
+	for(n = 0; n < len; n++)
+		free_opt2attr(&values[n], opts + n);
+}
+
 
 #define MAX_FILENAMES 1024
 int rnd_hid_parse_command_line(int *argc, char ***argv)
