@@ -139,6 +139,11 @@ struct rnd_export_opt_s {
    read-only opts; do this once, at init. */
 void rnd_hid_load_defaults(rnd_hid_t *hid, const rnd_export_opt_t *opts, int len);
 
+/* [4.4.0] Free all memory allocated by rnd_hid_load_defaults() by clearing
+   some fields in opts; should be ran in plugin uninit to avoid memory leaks */
+void rnd_hid_free_defaults(rnd_hid_t *hid, const rnd_export_opt_t *opts, int len);
+
+
 /* The selected HID or export plugin (and potentially
    dependent exporter plugins) register their options and command line
    options will be looked up in these. Plugins not participating in the
