@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *  Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA.
  *
  *  Contact:
  *    Project page: http://www.repo.hu/projects/librnd
@@ -631,14 +631,19 @@ int rnd_hid_cfg_keys_input_(rnd_design_t *hl, rnd_hid_cfg_keys_t *km, rnd_hid_cf
 		ns = htpp_get(phash, &addr);
 	}
 
-	/* already in the tree */
+	/* if still not found, break the sequence (invalid key seq by thelast stroke) */
 	if (ns == NULL) {
+		static rnd_hid_cfg_keyseq_t bad_ns = {0};
+		km->seq_len_action = (*seq_len)+1;
+		seq[*seq_len] = &bad_ns;
 		(*seq_len) = 0;
+		rnd_event(hl, RND_EVENT_USER_INPUT_KEY, NULL);
 		return -1;
 	}
 
 	seq[*seq_len] = ns;
 	(*seq_len)++;
+	km->seq_len_action = 0;
 
 	/* found a terminal node with an action */
 	if (ns->action_node != NULL) {
