@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *  Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA.
  *
  *  Contact:
  *    Project page: http://www.repo.hu/projects/librnd
@@ -101,14 +101,14 @@ typedef struct rnd_hid_row_s {
 
 typedef struct {
 	gdl_list_t rows; /* ordered list of first level rows (tree root) */
-	htsp_t paths;    /* translate first column paths iinto (rnd_hid_row_t *) */
+	htsp_t paths;    /* translate first column paths into (rnd_hid_row_t *) */
 	rnd_hid_attribute_t *attrib;
 	const char **hdr; /* optional column headers (NULL means disable header) */
 
 	/* optional callbacks the user set after widget creation */
 	void *user_ctx;
 	void (*user_free_cb)(rnd_hid_attribute_t *attrib, void *hid_ctx, rnd_hid_row_t *row); /* should free user data only; cell[] strings are free'd by DAD */
-	void (*user_selected_cb)(rnd_hid_attribute_t *attrib, void *hid_ctx, rnd_hid_row_t *row);
+	void (*user_selected_cb)(rnd_hid_attribute_t *attrib, void *hid_ctx, rnd_hid_row_t *row); /* tree: called back on cursor and/or selection change; the standard "changed" callback is made on row activation (double click or enter/space) */
 	int (*user_browse_activate_cb)(rnd_hid_attribute_t *attrib, void *hid_ctx, rnd_hid_row_t *row); /* returns non-zero if the row should auto-activate while browsing (e.g. stepping with arrow keys) */
 	const char *(*user_copy_to_clip_cb)(rnd_hid_attribute_t *attrib, void *hid_ctx, rnd_hid_row_t *row); /* returns the string to copy to clipboard for the given row (if unset, first column text is used) */
 
