@@ -136,6 +136,8 @@ static void set_clip(render_priv_t *priv, GdkGC *gc)
 		gdk_gc_set_clip_mask(gc, NULL);
 }
 
+#define THRESHOLD ((rnd_coord_t)(RND_COORD_MAX/2-1))
+
 static inline void ghid_gdk_draw_grid_global(rnd_design_t *hidlib)
 {
 	render_priv_t *priv = ghidgui->port.render_priv;
@@ -178,12 +180,20 @@ static inline void ghid_gdk_draw_grid_global(rnd_design_t *hidlib)
 	if (Vy(y2) >= ghidgui->port.view.canvas_height)
 		y2 -= grd;
 
+	if ((x1 < -THRESHOLD) && (x2 > THRESHOLD)) {
+		/* With large negative x1 and large positive x2 the expression (x2-x1)
+		   would overflow and n would be very small. In that case rather divide
+		   each component and combine the result. We need +2 instead of +1 because
+		   each division may round down */
+		n = (x2/grd) - (x1/grd) + 2;
+	}
+	else {
+		n = (x2 - x1) / grd + 1;
+		if (n <= 0)
+			n = 1;
+	}
 
-	n = (x2 - x1) / grd + 1;
-	if (n <= 0)
-		n = 1;
-
-	if (n > npoints) {
+	if ((n+10) > npoints) {
 		npoints = n + 10;
 		points = (GdkPoint *) realloc(points, npoints * sizeof(GdkPoint));
 	}
@@ -191,7 +201,7 @@ static inline void ghid_gdk_draw_grid_global(rnd_design_t *hidlib)
 	if (rnd_conf.editor.cross_grid) {
 		n = n*2;
 
-		if (n > npoints3) {
+		if ((n+30) > npoints3) {
 			npoints3 = n + 30;
 			points3 = (GdkPoint *) realloc(points3, npoints3 * sizeof(GdkPoint));
 		}
