@@ -3,9 +3,9 @@
 #include <stdio.h>
 
 #include <librnd/core/color_cache.h>
-#include <librnd/core/hid_attrib.h>
-#include <librnd/core/hidlib_conf.h>
-#include <librnd/core/pixmap.h>
+#include <librnd/hid/hid_attrib.h>
+#include <librnd/core/rnd_conf.h>
+#include <librnd/hid/pixmap.h>
 #include <librnd/core/globalconst.h>
 
 #include <librnd/plugins/lib_hid_common/clip.h>
@@ -286,12 +286,12 @@ static gboolean ghid_gl_drawing_area_expose_cb(GtkWidget *widget, rnd_gtk_expose
 }
 
 
-static gboolean ghid_gl_preview_expose(GtkWidget *widget, rnd_gtk_expose_t *ev, rnd_hid_expose_t expcall, rnd_hid_expose_ctx_t *ctx)
+static gboolean ghid_gl_preview_expose(GtkWidget *widget, rnd_gtk_expose_t *ev, rnd_hid_preview_expose_t expcall, rnd_hid_expose_ctx_t *ctx)
 {
 	GdkGLContext *pGlContext = gtk_widget_get_gl_context(widget);
 	GdkGLDrawable *pGlDrawable = gtk_widget_get_gl_drawable(widget);
 	GtkAllocation allocation;
-	rnd_hidlib_t *hidlib = ghidgui->hidlib;
+	rnd_design_t *hidlib = ghidgui->hidlib;
 	rnd_gtk_preview_t *preview = RND_GTK_PREVIEW(widget);
 
 	gtkc_widget_get_allocation(widget, &allocation);
