@@ -3,8 +3,8 @@
 #include <stdlib.h>
 
 #include <librnd/core/plugins.h>
-#include <librnd/core/hid_init.h>
-#include <librnd/core/hidlib_conf.h>
+#include <librnd/hid/hid_init.h>
+#include <librnd/core/rnd_conf.h>
 
 #include <librnd/plugins/lib_hid_gl/hidgl.h>
 
