@@ -22,11 +22,11 @@
 #include <librnd/hid/hid_init.h>
 #include "ltf_stdarg.h"
 #include <librnd/core/misc_util.h>
+#include "render.h"
+
 #include "dialogs.h"
 
-
 int rnd_ltf_ok;
-extern rnd_design_t *ltf_hidlib;
 
 
 #define COMPONENT_SIDE_NAME "(top)"
@@ -42,7 +42,7 @@ void rnd_ltf_winplace(Display *dsp, Window w, const char *id, int defx, int defy
 	plc[2] = defx;
 	plc[3] = defy;
 
-	rnd_event(ltf_hidlib, RND_EVENT_DAD_NEW_DIALOG, "psp", NULL, id, plc);
+	rnd_event(xrnd.dsg, RND_EVENT_DAD_NEW_DIALOG, "psp", NULL, id, plc);
 
 	if (rnd_conf.editor.auto_place) {
 		if ((plc[2] > 0) && (plc[3] > 0) && (plc[0] >= 0) && (plc[1] >= 0)) {
@@ -96,7 +96,7 @@ static void ltf_winplace_cfg(Display *dsp, Window win, void *ctx, const char *id
 
 			/* restore the original window position (either what the code wants or
 			   what we learned from the GUI */
-			rnd_event(ltf_hidlib, RND_EVENT_DAD_NEW_DIALOG, "psp", NULL, id, plc);
+			rnd_event(xrnd.dsg, RND_EVENT_DAD_NEW_DIALOG, "psp", NULL, id, plc);
 			if ((plc[0] >= 0) && (plc[1] >= 0)) {
 				x = plc[0];
 				y = plc[1];
@@ -115,7 +115,7 @@ static void ltf_winplace_cfg(Display *dsp, Window win, void *ctx, const char *id
 		XGetGeometry(dsp, win, &rw, &tmp, &tmp, &w, &h, &brd, &depth);
 		x -= wplc_hackx;
 		y -= wplc_hacky;
-		rnd_event(ltf_hidlib, RND_EVENT_DAD_NEW_GEO, "psiiii", ctx, id, (int)x, (int)y, (int)w, (int)h);
+		rnd_event(xrnd.dsg, RND_EVENT_DAD_NEW_GEO, "psiiii", ctx, id, (int)x, (int)y, (int)w, (int)h);
 	}
 }
 
@@ -679,7 +679,7 @@ void lesstif_attr_dlg_new(rnd_hid_t *hid, const char *id, rnd_hid_attribute_t *a
 	ctx = calloc(sizeof(lesstif_attr_dlg_t), 1);
 	*hid_ctx_out = ctx;
 	ctx->creating = 1;
-	ctx->hidlib = ltf_hidlib;
+	ctx->hidlib = xrnd.dsg;
 	ctx->attrs = attrs;
 	ctx->n_attrs = n_attrs;
 	ctx->caller_data = caller_data;
@@ -757,7 +757,7 @@ void *lesstif_attr_sub_new(Widget parent_box, rnd_hid_attribute_t *attrs, int n_
 
 	ctx = calloc(sizeof(lesstif_attr_dlg_t), 1);
 	ctx->creating = 1;
-	ctx->hidlib = ltf_hidlib;
+	ctx->hidlib = xrnd.dsg;
 	ctx->attrs = attrs;
 	ctx->n_attrs = n_attrs;
 	ctx->caller_data = caller_data;
@@ -1006,13 +1006,13 @@ static fgw_error_t rnd_act_DoWindows(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	if (strcmp(a, "1") == 0 || rnd_strcasecmp(a, "Layout") == 0) {
 	}
 	else if (strcmp(a, "2") == 0 || rnd_strcasecmp(a, "Library") == 0) {
-		rnd_actionva(ltf_hidlib, "LibraryDialog", NULL);
+		rnd_actionva(xrnd.dsg, "LibraryDialog", NULL);
 	}
 	else if (strcmp(a, "3") == 0 || rnd_strcasecmp(a, "Log") == 0) {
-		rnd_actionva(ltf_hidlib, "LogDialog", NULL);
+		rnd_actionva(xrnd.dsg, "LogDialog", NULL);
 	}
 	else if (strcmp(a, "4") == 0 || rnd_strcasecmp(a, "Netlist") == 0) {
-		rnd_actionva(ltf_hidlib, "NetlistDialog", NULL);
+		rnd_actionva(xrnd.dsg, "NetlistDialog", NULL);
 	}
 	else {
 		RND_ACT_FAIL(DoWindows);
