@@ -30,14 +30,10 @@ extern int lesstif_key_event(XKeyEvent *);
 extern int lesstif_button_event(Widget w, XEvent * e);
 
 extern void lesstif_need_idle_proc(void);
-extern void lesstif_show_crosshair(int);
 extern void lesstif_invalidate_all(rnd_hid_t *hid);
-extern void rnd_ltf_coords_to_design(int, int, rnd_coord_t *, rnd_coord_t *);
 extern int lesstif_get_xy(const char *msg);
 extern void lesstif_update_widget_flags(rnd_hid_t *hid, const char *cookie);
 extern int lesstif_call_action(const char *, int, char **);
-extern void lesstif_pan_fixup(void);
-extern Pixel lesstif_parse_color(const rnd_color_t *value);
 extern void lesstif_update_layer_groups();
 extern void lesstif_update_status_line();
 void *lesstif_attr_sub_new(Widget parent_box, rnd_hid_attribute_t *attrs, int n_attrs, void *caller_data);
@@ -53,7 +49,6 @@ int rnd_ltf_wait_for_dialog_noclose(Widget w);
 #endif
 
 #define need_idle_proc lesstif_need_idle_proc
-#define show_crosshair lesstif_show_crosshair
 
 /*
  * Motif comes from a time when even constant strings where
