@@ -1,15 +1,15 @@
 #include "ltf_stdarg.h"
+#include "render.h"
 Arg stdarg_args[30];
 int stdarg_n;
 
-extern Colormap lesstif_colormap;
 extern Display *lesstif_display;
 
 void stdarg_do_color(const rnd_color_t *value, char *which)
 {
 	XColor color;
-	if (XParseColor(lesstif_display, lesstif_colormap, value->str, &color))
-		if (XAllocColor(lesstif_display, lesstif_colormap, &color)) {
+	if (XParseColor(lesstif_display, xrnd.colormap, value->str, &color))
+		if (XAllocColor(lesstif_display, xrnd.colormap, &color)) {
 			stdarg(which, color.pixel);
 		}
 }
@@ -17,8 +17,8 @@ void stdarg_do_color(const rnd_color_t *value, char *which)
 void stdarg_do_color_str(const char *value, char *which)
 {
 	XColor color;
-	if (XParseColor(lesstif_display, lesstif_colormap, value, &color))
-		if (XAllocColor(lesstif_display, lesstif_colormap, &color)) {
+	if (XParseColor(lesstif_display, xrnd.colormap, value, &color))
+		if (XAllocColor(lesstif_display, xrnd.colormap, &color)) {
 			stdarg(which, color.pixel);
 		}
 }
