@@ -27,7 +27,7 @@
 
 #include <librnd/plugins/lib_hid_common/menu_helper.h>
 
-extern rnd_design_t *ltf_hidlib;
+#include "render.h"
 
 Widget lesstif_menubar;
 rnd_conf_hid_id_t lesstif_menuconf_id = -1;
@@ -94,7 +94,7 @@ void lesstif_update_widget_flags(rnd_hid_t *hid, const char *cookie)
 {
 	int i;
 
-	if (ltf_hidlib == NULL)
+	if (xrnd.dsg == NULL)
 		return;
 
 	if (rnd_menu_sys.inhibit)
@@ -107,7 +107,7 @@ void lesstif_update_widget_flags(rnd_hid_t *hid, const char *cookie)
 		if (wflags[i].w == NULL)
 			continue;
 
-		v = rnd_hid_get_flag(ltf_hidlib, wflags[i].flagname);
+		v = rnd_hid_get_flag(xrnd.dsg, wflags[i].flagname);
 		if (v < 0) {
 			XtSetArg(args[0], wflags[i].xres, 0);
 			XtSetArg(args[1], XtNsensitive, 0);
@@ -157,7 +157,7 @@ int lesstif_get_xy(const char *message)
 	void *chst = NULL;
 
 	if (rnd_app.crosshair_suspend != NULL)
-		chst = rnd_app.crosshair_suspend(ltf_hidlib);
+		chst = rnd_app.crosshair_suspend(xrnd.dsg);
 	XtManageChild(m_click);
 	stdarg_n = 0;
 	stdarg(XmNlabelString, ls);
@@ -175,7 +175,7 @@ int lesstif_get_xy(const char *message)
 	have_xy = 1;
 	XtUnmanageChild(m_click);
 	if (rnd_app.crosshair_restore != NULL)
-		rnd_app.crosshair_restore(ltf_hidlib, chst);
+		rnd_app.crosshair_restore(xrnd.dsg, chst);
 	return pressed_esc ? -1 : 0;
 }
 
@@ -192,7 +192,7 @@ int lesstif_get_coords(rnd_hid_t *hid, const char *msg, rnd_coord_t *px, rnd_coo
 		block_xy = 0;
 	}
 	if (have_xy)
-		rnd_ltf_coords_to_design(action_x, action_y, px, py);
+		xrnd_coords_to_design(action_x, action_y, px, py);
 
 	return res;
 }
@@ -212,7 +212,7 @@ static void callback(Widget w, lht_node_t * node, XmPushButtonCallbackStruct * p
 		   but opening a menu should reset it so get_coords() needs to ask */
 		have_xy = 0;
 	}
-	lesstif_show_crosshair(0);
+	xrnd_show_crosshair(0);
 	if (pbcs->event && pbcs->event->type == KeyPress) {
 		Dimension wx, wy;
 		Widget aw = XtWindowToWidget(display, pbcs->event->xkey.window);
@@ -241,7 +241,7 @@ static void callback(Widget w, lht_node_t * node, XmPushButtonCallbackStruct * p
 		XtPopdown(ltf_popup_active_md->sub);
 
 	lesstif_need_idle_proc();
-	rnd_hid_cfg_action(ltf_hidlib, node);
+	rnd_hid_cfg_action(xrnd.dsg, node);
 
 
 	ltf_popup_active = 0;
@@ -327,7 +327,7 @@ int lesstif_key_event(XKeyEvent * e)
 
 /*	printf("KEY lookup: mod=%x sym=%x/%d\n", mods, sym, slen); */
 TODO("TODO#3: pass on raw and translated keys")
-	slen = rnd_hid_cfg_keys_input(ltf_hidlib, &lesstif_keymap, mods, sym, sym);
+	slen = rnd_hid_cfg_keys_input(xrnd.dsg, &lesstif_keymap, mods, sym, sym);
 	if (slen <= 0)
 		return 1;
 
@@ -341,7 +341,7 @@ TODO("TODO#3: pass on raw and translated keys")
 
 	/* Parsing actions may not return until more user interaction
 	   happens.  */
-	rnd_hid_cfg_keys_action(ltf_hidlib, &lesstif_keymap);
+	rnd_hid_cfg_keys_action(xrnd.dsg, &lesstif_keymap);
 
 	return 1;
 }
