@@ -74,8 +74,8 @@ static void ltf_reg_mouse_cursor(rnd_hid_t *hid, int idx, const char *name, cons
 		XColor fg, bg;
 
 		mc->named_shape = -1;
-		mc->pixel = XCreateBitmapFromData(display, window, (const char *)pixel, 16, 16);
-		mc->mask = XCreateBitmapFromData(display, window, (const char *)mask, 16, 16);
+		mc->pixel = XCreateBitmapFromData(display, xrnd.window, (const char *)pixel, 16, 16);
+		mc->mask = XCreateBitmapFromData(display, xrnd.window, (const char *)mask, 16, 16);
 
 		fg.red = fg.green = fg.blue = 65535;
 		bg.red = bg.green = bg.blue = 0;
@@ -94,13 +94,13 @@ static void ltf_set_mouse_cursor(rnd_hid_t *hid, int idx)
 		if (mc == NULL) {
 			if (ltf_cursor_unknown == 0)
 				ltf_cursor_unknown = XCreateFontCursor(display, XC_mouse);
-			XDefineCursor(display, window, ltf_cursor_unknown);
+			XDefineCursor(display, xrnd.window, ltf_cursor_unknown);
 		}
 		else
-			XDefineCursor(display, window, mc->cursor);
+			XDefineCursor(display, xrnd.window, mc->cursor);
 	}
 	else
-		XDefineCursor(display, window, ltf_cursor_override);
+		XDefineCursor(display, xrnd.window, ltf_cursor_override);
 }
 
 static void ltf_mouse_uninit(void)
