@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *  Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA.
  *
  *  Contact:
  *    Project page: http://www.repo.hu/projects/librnd
@@ -62,11 +62,11 @@ void rnd_ltf_preview_zoom_update(rnd_ltf_preview_t *pd)
 
 	/* might be called from within an user expose callback - should affect the rest of the drawing */
 	if (pd->expose_lock) {
-		view_left_x = pd->x1;
-		view_top_y = pd->y1;
-		view_zoom = pd->zoom;
-		view_width = pd->x2;
-		view_height = pd->y2;
+		xrnd.view_left_x = pd->x1;
+		xrnd.view_top_y = pd->y1;
+		xrnd.view_zoom = pd->zoom;
+		xrnd.view_width = pd->x2;
+		xrnd.view_height = pd->y2;
 	}
 }
 
@@ -86,88 +86,28 @@ void rnd_ltf_preview_getxy(rnd_ltf_preview_t *pd, int px, int py, rnd_coord_t *d
 	*dst_y = y;
 }
 
-#define apply_flip(pd) \
-	if (pd->flip_local) { \
-		rnd_conf_force_set_bool(rnd_conf.editor.view.flip_x, pd->flip_x); \
-		rnd_conf_force_set_bool(rnd_conf.editor.view.flip_y, pd->flip_y); \
-	} \
-	else if (!pd->flip_global) { \
-		rnd_conf_force_set_bool(rnd_conf.editor.view.flip_x, 0); \
-		rnd_conf_force_set_bool(rnd_conf.editor.view.flip_y, 0); \
-	}
 
 void rnd_ltf_preview_redraw(rnd_ltf_preview_t *pd)
 {
-	int save_vx, save_vy, save_vw, save_vh;
-	int save_fx, save_fy;
-	double save_vz;
-	Pixmap save_px, save_main_px, save_mask_px, save_mask_bm;
-	XGCValues gcv;
 	GC gc;
-	rnd_coord_t save_cpp;
+	XGCValues gcv;
 
 	if (pd->expose_lock)
 		return;
 
-	pd->expose_lock = 1;
-
 	memset(&gcv, 0, sizeof(gcv));
 	gcv.graphics_exposures = 0;
 	gc = XtGetGC(pd->pw, GCGraphicsExposures, &gcv);
 
-	save_vx = view_left_x;
-	save_vy = view_top_y;
-	save_vz = view_zoom;
-	save_vw = view_width;
-	save_vh = view_height;
-	save_fx = rnd_conf.editor.view.flip_x;
-	save_fy = rnd_conf.editor.view.flip_y;
-	save_px = main_pixmap;
-	save_main_px = main_pixmap;
-	save_mask_px = mask_pixmap;
-	save_mask_bm = mask_bitmap;
-	save_cpp = rnd_gui->coord_per_pix;
-	main_pixmap = XCreatePixmap(XtDisplay(pd->pw), XtWindow(pd->pw), pd->v_width, pd->v_height, widget_depth(pd->pw));
-	mask_pixmap = XCreatePixmap(XtDisplay(pd->pw), XtWindow(pd->pw), pd->v_width, pd->v_height, widget_depth(pd->pw));
-	mask_bitmap = XCreatePixmap(XtDisplay(pd->pw), XtWindow(pd->pw), pd->v_width, pd->v_height, 1);
-	pixmap = main_pixmap;
-	view_left_x = pd->x1;
-	view_top_y = pd->y1;
-	view_zoom = pd->zoom;
-	view_width = pd->x2;
-	view_height = pd->y2;
-	apply_flip(pd);
+	pd->expose_lock = 1;
 
-	XFillRectangle(display, pixmap, bg_gc, 0, 0, pd->v_width, pd->v_height);
+	xrnd_render_preview(&lesstif_hid, XtDisplay(pd->pw), XtWindow(pd->pw),
+		widget_depth(pd->pw), gc, pd->v_width, pd->v_height,
+		pd->x1, pd->y1, pd->x2, pd->y2, pd->zoom, &pd->exp_ctx, 
+		pd->flip_local, pd->flip_global, pd->flip_x, pd->flip_y);
 
-	pd->exp_ctx.view.X1 = pd->x1;
-	pd->exp_ctx.view.Y1 = pd->y1;
-	pd->exp_ctx.view.X2 = pd->x2;
-	pd->exp_ctx.view.Y2 = pd->y2;
-
-	pd->exp_ctx.coord_per_pix = view_zoom;
-	rnd_gui->coord_per_pix = view_zoom;
-	rnd_app.expose_preview(&lesstif_hid, &pd->exp_ctx);
-
-	XCopyArea(lesstif_display, pixmap, XtWindow(pd->pw), gc, 0, 0, pd->v_width, pd->v_height, 0, 0);
 	XtReleaseGC(pd->pw, gc);
 
-	view_left_x = save_vx;
-	view_top_y = save_vy;
-	view_zoom = save_vz;
-	view_width = save_vw;
-	view_height = save_vh;
-	XFreePixmap(lesstif_display, main_pixmap);
-	XFreePixmap(lesstif_display, mask_pixmap);
-	XFreePixmap(lesstif_display, mask_bitmap);
-	main_pixmap = save_main_px;
-	mask_pixmap = save_mask_px;
-	mask_bitmap = save_mask_bm;
-	pixmap = save_px;
-	rnd_gui->coord_per_pix = save_cpp;
-	rnd_conf_force_set_bool(rnd_conf.editor.view.flip_x, save_fx);
-	rnd_conf_force_set_bool(rnd_conf.editor.view.flip_y, save_fy);
-
 	pd->expose_lock = 0;
 }
 
