@@ -35,12 +35,4 @@
 #include <Xm/ToggleB.h>
 #include <Xm/Xm.h>
 
-#ifdef RND_HAVE_XRENDER
-#include <X11/extensions/Xrender.h>
-#endif /* RND_HAVE_XRENDER */
-
-#ifdef RND_HAVE_XINERAMA
-#include <X11/extensions/Xinerama.h>
-#endif /* RND_HAVE_XINERAMA */
-
 #undef Mask
