@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *  Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA.
  *
  *  Contact:
  *    Project page: http://www.repo.hu/projects/librnd
@@ -32,6 +32,8 @@
 #include <librnd/hid/hid_init.h>
 
 #include <libmbtk/backend.h>
+#include <libmbtk/timer.h>
+#define MBTK_XLIB_WANT_NATIVE 1
 #include <libmbtk/backend/xlib.h>
 
 #include <librnd/plugins/lib_mbtk_common/glue_hid.h>
@@ -39,6 +41,7 @@
 const char *mbtkx_cookie = "miniboxtk hid, xlib backend";
 
 rnd_hid_t mbtkx_hid;
+static rnd_mbtk_t mbtkx_global;
 
 static int rnd_mbtk_xlib_init_backend(rnd_mbtk_t *mctx, int *argc, char **argv[])
 {
@@ -47,7 +50,10 @@ static int rnd_mbtk_xlib_init_backend(rnd_mbtk_t *mctx, int *argc, char **argv[]
 		return -1;
 	}
 
+	TODO("make this configurable");
 	mctx->default_font = "-*-fixed-medium-*-*-*-15-*-*-*-*-*-*-*";
+	mctx->bold_font = "-*-fixed-bold-*-*-*-15-*-*-*-*-*-*-*";
+	mctx->italic_font = "-*-fixed-medium-o-*-*-15-*-*-*-*-*-*-*";
 
 	return 0;
 }
@@ -57,6 +63,9 @@ int mbtk_xlib_parse_arguments(rnd_hid_t *hid, int *argc, char ***argv)
 	return rnd_mbtk_parse_arguments(hid, argc, argv);
 }
 
+#include "glue_render.c"
+
+
 int pplg_check_ver_hid_mbtk_xlib(int ver_needed) { return 0; }
 
 void pplg_uninit_hid_mbtk_xlib(void)
@@ -67,13 +76,16 @@ int pplg_init_hid_mbtk_xlib(void)
 {
 	RND_API_CHK_VER;
 
-	rnd_mbtk_glue_hid_init(&mbtkx_hid, rnd_mbtk_xlib_init_backend);
+	mbtkx_global.init_backend = rnd_mbtk_xlib_init_backend;
+	rnd_mbtk_glue_hid_init(&mbtkx_hid,  &mbtkx_global);
 
 	mbtkx_hid.parse_arguments = mbtk_xlib_parse_arguments;
 
 	mbtkx_hid.name = "mbtk_xlib";
 	mbtkx_hid.description = "miniboxtk xlib - software rendering on X11";
 
+	mbtkx_glue_render_init();
+
 	rnd_hid_register_hid(&mbtkx_hid);
 
 	return 0;
