@@ -360,11 +360,18 @@ void rnd_ps_page_background(rnd_ps_t *pctx, int has_outline, int page_is_route,
 
 	if (!has_outline || pctx->invert) {
 		if (page_is_route) {
+			const char *verb;
+
+			/* Use lineto for drawing the frame rectangle or the filled rectangle
+			   background for inversion; when neither is requested, use moveto so
+			   nothing is drawn */
+			verb = (pctx->enable_frame || pctx->invert) ? "lineto" : "moveto";
+
 			rnd_fprintf(pctx->outf, "0 setgray %mi setlinewidth", min_wid);
 			rnd_fprintf(pctx->outf, " %mi %mi moveto ", pctx->hidlib->dwg.X1, pctx->hidlib->dwg.Y1);
-			rnd_fprintf(pctx->outf, " %mi %mi moveto ", pctx->hidlib->dwg.X1, pctx->hidlib->dwg.Y2);
-			rnd_fprintf(pctx->outf, " %mi %mi moveto ", pctx->hidlib->dwg.X2, pctx->hidlib->dwg.Y2);
-			rnd_fprintf(pctx->outf, " %mi %mi moveto ", pctx->hidlib->dwg.X2, pctx->hidlib->dwg.Y1);
+			rnd_fprintf(pctx->outf, " %mi %mi %s ", pctx->hidlib->dwg.X1, pctx->hidlib->dwg.Y2, verb);
+			rnd_fprintf(pctx->outf, " %mi %mi %s ", pctx->hidlib->dwg.X2, pctx->hidlib->dwg.Y2, verb);
+			rnd_fprintf(pctx->outf, " %mi %mi %s ", pctx->hidlib->dwg.X2, pctx->hidlib->dwg.Y1, verb);
 			rnd_fprintf(pctx->outf, " closepath %s\n", pctx->invert ? "fill" : "stroke");
 		}
 	}
