@@ -1,7 +1,6 @@
 #include "compat.h"
 
 #define GDKC_HAND2       GDK_HAND2
-#define GDKC_WATCH       GDK_WATCH
 #define GDKC_DRAPED_BOX  GDK_DRAPED_BOX
 #define GDKC_LEFT_PTR    GDK_LEFT_PTR
 
@@ -12,6 +11,7 @@ typedef struct {
 
 static const named_cursor_t named_cursors[] = {
 	{"question_arrow", GDK_QUESTION_ARROW},
+	{"busy",     GDK_WATCH},
 	{"left_ptr", GDK_LEFT_PTR},
 	{"hand", GDK_HAND1},
 	{"crosshair", GDK_CROSSHAIR},
