@@ -1,7 +1,6 @@
 #include "compat.h"
 
 #define GDKC_HAND2       "pointer"
-#define GDKC_WATCH       "progress"
 #define GDKC_DRAPED_BOX  "all-scroll"
 #define GDKC_LEFT_PTR    "default"
 
@@ -12,6 +11,7 @@ typedef struct {
 
 static const named_cursor_t named_cursors[] = {
 	{"question_arrow", "help"},
+	{"busy",           "progress"},
 	{"left_ptr",       "default"},
 	{"hand",           "grabbing"},
 	{"crosshair",      "crosshair"},
