@@ -4,19 +4,19 @@
 
 static inline void rnd_gtk_preview_redraw_all(rnd_gtk_preview_t *preview)
 {
-	TODO("implement this for gtk4: gtk_gl_area_queue_render() - ignore rectangle, gl redraws everything");
+	gtk_gl_area_queue_render(GTK_GL_AREA(preview));
 }
 
 static gboolean rnd_gtk_preview_expose(GtkWidget *widget, rnd_gtk_expose_t *ev);
 
-static gboolean rnd_gtk_preview_render(GtkGLArea *area, GdkGLContext *context, void *udata)
+static gboolean rnd_gtk_preview_render(GtkGLArea *area, GdkGLContext *context)
 {
 	return rnd_gtk_preview_expose(GTK_WIDGET(area), NULL);
 }
 
 
 #define RND_GTK_EXPOSE_EVENT_SET(obj) \
-	g_signal_connect(obj, "render", G_CALLBACK(rnd_gtk_preview_render), NULL);
+	((GtkGLAreaClass *)obj)->render = rnd_gtk_preview_render
 
 
 #include <librnd/plugins/lib_gtk_common/wt_preview.c>
