@@ -22,7 +22,7 @@ typedef struct rnd_gtk_command_s {
 	gtkc_event_xyz_t kpress, krelease;
 } rnd_gtk_command_t;
 
-void rnd_gtk_handle_user_command(rnd_hidlib_t *hl, rnd_gtk_command_t *ctx, rnd_bool raise);
+void rnd_gtk_handle_user_command(rnd_design_t *hl, rnd_gtk_command_t *ctx, rnd_bool raise);
 char *rnd_gtk_command_entry_get(rnd_gtk_command_t *ctx, const char *prompt, const char *command);
 
 /* Update the prompt text before the command entry - call it when any of conf_core.rc.cli_* change */
