@@ -1,7 +1,7 @@
 #ifndef RND_GTK_IN_MOUSE_H
 #define RND_GTK_IN_MOUSE_H
 
-#include <librnd/core/hid_cfg_input.h>
+#include <librnd/hid/hid_cfg_input.h>
 #include "rnd_gtk.h"
 
 #include <gtk/gtk.h>
@@ -23,8 +23,6 @@ gboolean rnd_gtk_button_release_cb(GtkWidget *drawing_area, long x, long y, long
 void rnd_gtk_reg_mouse_cursor(rnd_gtk_t *ctx, int idx, const char *name, const unsigned char *pixel, const unsigned char *mask);
 void rnd_gtk_set_mouse_cursor(rnd_gtk_t *ctx, int idx);
 
-void rnd_gtk_watch_cursor(rnd_gtk_t *ctx); /* Override the cursor appearance to signifies a wait state */
-void rnd_gtk_point_cursor(rnd_gtk_t *ctx, rnd_bool grabbed); /* Override the cursor appearance to signifies a point is found */
 void rnd_gtk_mode_cursor(rnd_gtk_t *ctx); /* Changes the normal cursor appearance according to last set mode, but respect override */
 void rnd_gtk_restore_cursor(rnd_gtk_t *ctx); /* Remove override and restore the mode cursor */
 
