@@ -43,6 +43,9 @@ typedef struct {
 				RND_CFT_BOOLEAN dir_grp;         /* group by directories by default when the dialog opens */
 				RND_CFT_BOOLEAN icase;           /* case insensitive name sort by default */
 			} fsd;
+			const struct {
+				RND_CFT_INTEGER icons_per_page;  /* split toolbar icons into pages and never show more than this amount of icons at once, to keep the toolbar narrow (for small screen); when set to 0 there is no limit and all icons are presented on a single page */
+			} toolbar;
 		} lib_hid_common;
 
 	} plugins;
