@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *  Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA.
  *
  *  Contact:
  *    Project page: http://www.repo.hu/projects/librnd
@@ -60,6 +60,7 @@ fgw_error_t rnd_act_gui_PromptFor(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	RND_DAD_BEGIN_VBOX(dlg);
 		RND_DAD_LABEL(dlg, label);
 		RND_DAD_STRING(dlg);
+			RND_DAD_COMPFLAG(dlg, RND_HATF_EXPFILL);
 			ws = RND_DAD_CURRENT(dlg);
 			dlg[ws].val.str = rnd_strdup(default_str == NULL ? "" : default_str);
 			RND_DAD_ENTER_CB(dlg, prompt_enter_cb);
