@@ -2,7 +2,7 @@
  *                            COPYRIGHT
  *
  *  pcb-rnd, interactive printed circuit board design
- *  Copyright (C) 2018 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2018,2025 Tibor 'Igor2' Palinkas
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *  Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA.
  *
  *  Contact:
  *    Project page: http://www.repo.hu/projects/librnd
@@ -129,6 +129,8 @@ void rnd_dlg_pref_win_create(pref_ctx_t *ctx)
 			RND_DAD_HELP(ctx->dlg, "When enabled, attempt to set window size and position when a new window opens\nremembering geometry while the program is running;\nwindow geometry will be loaded from config files\nand try to resize and place windows accordingly.\nSizes can be saved once (golden arrangement)\nor at every exit (retrain last setup),\nsee below.");
 			ctx->win.wmaster = RND_DAD_CURRENT(ctx->dlg);
 			RND_DAD_CHANGE_CB(ctx->dlg, pref_win_master_cb);
+		RND_DAD_LABEL(ctx->dlg, "[LIMITATIONS tooltip]");
+			RND_DAD_HELP(ctx->dlg, "Does not work on Wayland because of a design decision of Wayland - you will need to get your compositor to remember window placement and geometry.");
 	RND_DAD_END(ctx->dlg);
 	RND_DAD_BEGIN_VBOX(ctx->dlg);
 		RND_DAD_COMPFLAG(ctx->dlg, RND_HATF_FRAME);
