@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *  Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA.
  *
  *  Contact:
  *    Project page: http://www.repo.hu/projects/librnd
@@ -41,17 +41,64 @@
 #include <librnd/core/conf_hid.h>
 #include <librnd/core/actions.h>
 
+#include "xpm.h"
+#include "dialogs_conf.h"
 #include "toolbar.h"
 
+extern conf_dialogs_t dialogs_conf;
+
 typedef struct {
 	rnd_hid_dad_subdialog_t sub;
 	int sub_inited, lock;
 	vti0_t tid2wid; /* tool ID to widget ID conversion - value 0 means no widget */
+	vti0_t icons;   /* tool icon widget IDs in order of appearance */
+	int curr_page;
+	int wpagebtns;  /* widget id of the box that hosts the up/down button */
 } toolbar_ctx_t;
 
 static toolbar_ctx_t toolbar;
 
-static void toolbar_design2dlg()
+RND_INLINE int get_max_page(void)
+{
+	if (dialogs_conf.plugins.lib_hid_common.toolbar.icons_per_page == 0)
+		return 1;
+	return (toolbar.icons.used / dialogs_conf.plugins.lib_hid_common.toolbar.icons_per_page);
+}
+
+static void toolbar_update_paging(void)
+{
+	int n, max_page, pid;
+
+	/* paging */
+	if ((toolbar.icons.used <= dialogs_conf.plugins.lib_hid_common.toolbar.icons_per_page) || (dialogs_conf.plugins.lib_hid_common.toolbar.icons_per_page <= 0)) {
+		/* everything fits onto a singe page - hide page switch buttons */
+		rnd_gui->attr_dlg_widget_hide(toolbar.sub.dlg_hid_ctx, toolbar.wpagebtns, 1);
+		return;
+	}
+
+	max_page = get_max_page();
+	if (toolbar.curr_page < 0)
+		toolbar.curr_page = 0;
+	else if (toolbar.curr_page > max_page)
+		toolbar.curr_page = max_page;
+
+	for(n = 0, pid = 0; n < toolbar.icons.used; n++) {
+		int wid = toolbar.icons.array[n], hidden;
+		if (dialogs_conf.plugins.lib_hid_common.toolbar.icons_per_page > 0) {
+			if ((n != 0) && ((n % dialogs_conf.plugins.lib_hid_common.toolbar.icons_per_page) == 0))
+				pid++;
+			hidden = (pid != toolbar.curr_page);
+		}
+		else
+			hidden = 0;
+		/*rnd_trace("[%d] wid=%d pid=%d curr=%d (max_page=%d) -> %d\n", n, wid, pid, toolbar.curr_page, max_page, hidden);*/
+		rnd_gui->attr_dlg_widget_hide(toolbar.sub.dlg_hid_ctx, wid, hidden);
+	}
+
+	rnd_gui->attr_dlg_widget_hide(toolbar.sub.dlg_hid_ctx, toolbar.wpagebtns, 0);
+}
+
+static void toolbar_design2dlg(void)
 {
 	rnd_toolid_t tid;
 
@@ -68,8 +115,33 @@ static void toolbar_design2dlg()
 		rnd_gui->attr_dlg_widget_state(toolbar.sub.dlg_hid_ctx, wid, st);
 	}
 	toolbar.lock = 0;
+	toolbar_update_paging();
 }
 
+static void toolbar_page_down_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
+{
+	int orig = toolbar.curr_page, max_page = get_max_page();
+
+	toolbar.curr_page++;
+	if (toolbar.curr_page > max_page)
+		toolbar.curr_page = 0;
+
+	if (orig != toolbar.curr_page)
+		toolbar_update_paging();
+}
+
+static void toolbar_page_up_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
+{
+	int orig = toolbar.curr_page;
+
+	toolbar.curr_page--;
+	if (toolbar.curr_page < 0)
+		toolbar.curr_page = get_max_page();
+	if (orig != toolbar.curr_page)
+		toolbar_update_paging();
+}
+
+
 static void toolbar_select_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
 {
 	ptrdiff_t tid;
@@ -100,6 +172,7 @@ static void toolbar_create_tool(rnd_toolid_t tid, rnd_tool_t *tool, const char *
 	wid = RND_DAD_CURRENT(toolbar.sub.dlg);
 	toolbar.sub.dlg[wid].user_data = (void *)(ptrdiff_t)tid;
 	vti0_set(&toolbar.tid2wid, tid, wid);
+	vti0_append(&toolbar.icons, wid);
 }
 
 static void toolbar_create_static(rnd_hid_cfg_t *cfg)
@@ -151,11 +224,25 @@ static void toolbar_create_dyn_all(void)
 
 static void toolbar_docked_create(rnd_hid_cfg_t *cfg)
 {
+	static const char arrow_hint[] = "There are more toolbar icon buttons than the maximum defined in the config node\nplugins/lib_hid_common/toolbar/icons_per_page\nso icons are sorted into multiple pages. The up and down arrows are used to select which page is shown.\nSet icons_per_page to 0 to disable.";
 	toolbar.tid2wid.used = 0;
+	toolbar.icons.used = 0;
 
 	RND_DAD_BEGIN_HBOX(toolbar.sub.dlg);
 		RND_DAD_COMPFLAG(toolbar.sub.dlg, RND_HATF_EXPFILL | RND_HATF_TIGHT);
 
+	/* page switch buttons on the left (stable side, won't jump away if there are less icons on a page) */
+		RND_DAD_BEGIN_VBOX(toolbar.sub.dlg);
+			toolbar.wpagebtns = RND_DAD_CURRENT(toolbar.sub.dlg);
+			RND_DAD_PICBUTTON(toolbar.sub.dlg, rnd_dlg_xpm_by_name("up"));
+				RND_DAD_CHANGE_CB(toolbar.sub.dlg, toolbar_page_up_cb);
+				RND_DAD_HELP(toolbar.sub.dlg, arrow_hint);
+			RND_DAD_PICBUTTON(toolbar.sub.dlg, rnd_dlg_xpm_by_name("down"));
+				RND_DAD_CHANGE_CB(toolbar.sub.dlg, toolbar_page_down_cb);
+				RND_DAD_HELP(toolbar.sub.dlg, arrow_hint);
+		RND_DAD_END(toolbar.sub.dlg);
+
+		/* toolbar icons */
 		toolbar_create_static(cfg);
 		toolbar_create_dyn_all();
 
@@ -164,8 +251,6 @@ static void toolbar_docked_create(rnd_hid_cfg_t *cfg)
 			RND_DAD_COMPFLAG(toolbar.sub.dlg, RND_HATF_EXPFILL);
 		RND_DAD_END(toolbar.sub.dlg);
 
-	/* later on dynamic tools would be displayed here */
-
 	RND_DAD_END(toolbar.sub.dlg);
 }
 
@@ -244,7 +329,7 @@ void rnd_toolbar_uninit(void)
 
 void rnd_toolbar_init(void)
 {
-	const char *tpaths[] = {"editor/mode",  NULL};
+	const char *tpaths[] = {"editor/mode", "plugins/lib_hid_common/toolbar/icons_per_page", NULL};
 	static rnd_conf_hid_callbacks_t tcb[sizeof(tpaths)/sizeof(tpaths[0])];
 
 	if (rnd_toolbar_inited)
@@ -273,3 +358,58 @@ fgw_error_t rnd_act_rnd_toolbar_uninit(fgw_arg_t *res, int argc, fgw_arg_t *argv
 	RND_ACT_IRES(0);
 	return 0;
 }
+
+/* DOC: rnd_toolbar_page.html */
+const char rnd_acts_rnd_toolbar_page[] = "rnd_toolbar_page(get|max|set|up|down, [pageidx])\n";
+const char rnd_acth_rnd_toolbar_page[] = "For ringdove apps: page accessor .";
+fgw_error_t rnd_act_rnd_toolbar_page(fgw_arg_t *res, int argc, fgw_arg_t *argv)
+{
+	const char *cmd;
+	int itmp;
+
+	RND_ACT_CONVARG(1, FGW_STR, rnd_toolbar_page, cmd = argv[1].val.str);
+	switch(*cmd) {
+		case 'g':
+			if (strcmp(cmd+1, "et") == 0) {
+				RND_ACT_IRES(toolbar.curr_page);
+				return 0;
+			}
+			break;
+		case 'm':
+			if (strcmp(cmd+1, "ax") == 0) {
+				RND_ACT_IRES(get_max_page());
+				return 0;
+			}
+			break;
+		case 's':
+			if (strcmp(cmd+1, "et") == 0) {
+				RND_ACT_IRES(toolbar.curr_page);
+				RND_ACT_CONVARG(2, FGW_INT, rnd_toolbar_page, itmp = argv[2].val.nat_int);
+				toolbar.curr_page = itmp;
+				toolbar_update_paging();
+				return 0;
+			}
+			break;
+
+		case 'u':
+			if ((cmd[1] == 'p') && (cmd[2] == '\0')) {
+				toolbar_page_up_cb(NULL, NULL, NULL);
+				RND_ACT_IRES(0);
+				return 0;
+			}
+			break;
+
+		case 'd':
+			if (strcmp(cmd+1, "own") == 0) {
+				toolbar_page_down_cb(NULL, NULL, NULL);
+				RND_ACT_IRES(0);
+				return 0;
+			}
+			break;
+
+	}
+
+	rnd_message(RND_MSG_ERROR, "rnd_toolbar_page(): invalid command (first arg): '%s'\n", cmd);
+	RND_ACT_IRES(-1);
+	return 0;
+}
