@@ -10,6 +10,8 @@
 #include "xpm/online_help.xpm"
 #include "xpm/plus.xpm"
 #include "xpm/minus.xpm"
+#include "xpm/up.xpm"
+#include "xpm/down.xpm"
 
 const char **rnd_dlg_xpm_by_name(const char *name)
 {
@@ -18,6 +20,8 @@ const char **rnd_dlg_xpm_by_name(const char *name)
 	if (strcmp(name, "online_help") == 0) return online_help_xpm;
 	if (strcmp(name, "plus") == 0) return plus_xpm;
 	if (strcmp(name, "minus") == 0) return minus_xpm;
+	if (strcmp(name, "up") == 0) return up_xpm;
+	if (strcmp(name, "down") == 0) return down_xpm;
 	return NULL;
 }
 
