@@ -18,7 +18,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *  Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA.
  *
  *  Contact:
  *    Project page: http://www.repo.hu/projects/librnd
@@ -270,12 +270,12 @@ void hidgl_fill_rect(rnd_coord_t x1, rnd_coord_t y1, rnd_coord_t x2, rnd_coord_t
 
 RND_INLINE void reserve_grid_points(int n, int n3)
 {
-	if (n > grid_point_capacity) {
+	if ((n+10) > grid_point_capacity) {
 		grid_point_capacity = n + 10;
 		grid_points = realloc(grid_points, grid_point_capacity * 2 * sizeof(GLfloat));
 	}
-	if (n3 > grid_point_capacity3) {
-		grid_point_capacity3 = n3 + 10;
+	if ((n3+30) > grid_point_capacity3) {
+		grid_point_capacity3 = n3 + 30;
 		grid_points3 = realloc(grid_points3, grid_point_capacity3 * 2 * sizeof(GLfloat));
 	}
 }
