@@ -1,6 +1,9 @@
 #include <librnd/hid/hid.h>
 #include <librnd/plugins/lib_mbtk_common/mbtk_common.h>
 
-void rnd_mbtk_glue_hid_init(rnd_hid_t *dst, int (*init_backend)(rnd_mbtk_t *mctx, int *argc, char **argv[]));
+void rnd_mbtk_glue_hid_init(rnd_hid_t *dst, rnd_mbtk_t *global);
 int rnd_mbtk_parse_arguments(rnd_hid_t *hid, int *argc, char ***argv);
 
+/* for chain calling */
+void rnd_mbtk_set_hidlib(rnd_hid_t *hid, rnd_design_t *hidlib);
+
