@@ -2,8 +2,6 @@
 #include <librnd/core/compat_misc.h>
 #include <librnd/hid/tool.h>
 
-static rnd_hid_cfg_keys_t rnd_mbtk_keymap;
-
 static unsigned short int rnd_mbtk_translate_key(const char *desc, int len)
 {
 	unsigned int key = 0;
@@ -13,6 +11,12 @@ static unsigned short int rnd_mbtk_translate_key(const char *desc, int len)
 
 	if (rnd_strcasecmp(desc, "Return") == 0)
 		desc = "Enter";
+	else if (rnd_strcasecmp(desc, "Delete") == 0)
+		desc = "Del";
+	else if (rnd_strcasecmp(desc, "Escape") == 0)
+		desc = "Esc";
+	else if (rnd_strcasecmp(desc, "Space") == 0)
+		return ' ';
 
 	key = mbtk_name2keysym(desc);
 	if (key == MBTK_KS_INVALID) {
@@ -43,13 +47,14 @@ static int rnd_mbtk_key_name(unsigned short int key_char, char *out, int out_len
 	return 0;
 }
 
-static int xlate_mods(mbtk_keymod_t km)
+static rnd_hid_cfg_mod_t mbtk_mod2cfg(mbtk_keymod_t km)
 {
-	int res = 0;
+	rnd_hid_cfg_mod_t res = 0;
 
 	if (km & MBTK_KM_SHIFT) res |= RND_M_Shift;
 	if (km & MBTK_KM_ALT)   res |= RND_M_Alt;
 	if (km & MBTK_KM_CTRL)  res |= RND_M_Ctrl;
+	/* ignored: MBTK_KM_KEYPAD */
 
 	return res;
 }
@@ -64,13 +69,16 @@ static mbtk_event_handled_t rnd_mbtk_key_release_cb(rnd_mbtk_t *mctx, mbtk_event
 {
 	int slen, mods;
 
+	if (ev->data.key.sym == MBTK_KS_ESC)
+		mctx->pressed_esc = 1;
+
 	if (mbtk_ks_is_modifier(ev->data.key.sym))
 		rnd_mbtk_note_event_location(0, 0, 0);
 
-	mods = xlate_mods(ev->data.key.mods);
-	slen = rnd_hid_cfg_keys_input(mctx->hidlib, &rnd_mbtk_keymap, mods, ev->data.key.sym, ev->data.key.edit);
+	mods = mbtk_mod2cfg(ev->data.key.mods);
+	slen = rnd_hid_cfg_keys_input(mctx->hidlib, &mctx->hc_keymap, mods, ev->data.key.sym, ev->data.key.edit);
 	if (slen > 0)
-		rnd_hid_cfg_keys_action(mctx->hidlib, &rnd_mbtk_keymap);
+		rnd_hid_cfg_keys_action(mctx->hidlib, &mctx->hc_keymap);
 
 	if (rnd_app.adjust_attached_objects != NULL)
 		rnd_app.adjust_attached_objects(mctx->hidlib);
@@ -85,3 +93,9 @@ TODO("do we need this?");
 
 	return MBTK_EVENT_HANDLED;
 }
+
+static mbtk_event_handled_t rnd_mbtk_stdin_input(rnd_mbtk_t *mctx, mbtk_event_t *ev)
+{
+	rnd_parse_actions(mctx->hidlib, ev->data.rstdin.data);
+	return MBTK_EVENT_HANDLED;
+}
