@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *  Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA.
  *
  *  Contact:
  *    Project page: http://www.repo.hu/projects/librnd
@@ -29,16 +29,30 @@
 #include <librnd/core/plugins.h>
 #include <librnd/hid/hid_init.h>
 
+#include <librnd/plugins/lib_mbtk_common/conf_internal.c>
+#include "lib_mbtk_conf.h"
+
+conf_lib_mbtk_t rnd_mbtk_conf;
+
 
 int pplg_check_ver_lib_mbtk_common(int ver_needed) { return 0; }
 
 void pplg_uninit_lib_mbtk_common(void)
 {
+	rnd_conf_unreg_intern(mbtk_conf_internal);
+	rnd_conf_unreg_fields("plugins/hid_mbtk/");
 }
 
 int pplg_init_lib_mbtk_common(void)
 {
 	RND_API_CHK_VER;
+
+	rnd_conf_reg_intern(mbtk_conf_internal);
+
+#define conf_reg(field,isarray,type_name,cpath,cname,desc,flags) \
+	rnd_conf_reg_field(rnd_mbtk_conf, field,isarray,type_name,cpath,cname,desc,flags);
+#include "lib_mbtk_conf_fields.h"
+
 	return 0;
 }
 
