@@ -80,12 +80,11 @@ static void rnd_mbtk_menu_update_checkboxes(rnd_mbtk_t *mctx, rnd_design_t *hidl
 }
 
 
-TODO("mbtk_glboal should come user_data, already set at registration");
-static rnd_mbtk_t mbtk_global;
 static void rnd_mbtk_confchg_checkbox(rnd_conf_native_t *cfg, int arr_idx, void *user_data)
 {
-	if ((mbtk_global.hid_active) && (mbtk_global.hidlib != NULL))
-		rnd_mbtk_menu_update_checkboxes(&mbtk_global, mbtk_global.hidlib);
+	rnd_mbtk_t *mctx = rnd_gui->hid_data;
+	if ((mctx->hid_active) && (mctx->hidlib != NULL))
+		rnd_mbtk_menu_update_checkboxes(mctx, mctx->hidlib);
 }
 
 
@@ -142,8 +141,8 @@ static mbtk_box_t *rnd_mbtk_menu_create_(rnd_mbtk_t *mctx, mbtk_widget_t *parent
 	/* Resolve accelerator and save it */
 	if (n_keydesc != NULL) {
 		if (n_action != NULL) {
-			rnd_hid_cfg_keys_add_by_desc(&rnd_mbtk_keymap, n_keydesc, n_action);
-			accel = rnd_hid_cfg_keys_gen_accel(&rnd_mbtk_keymap, n_keydesc, 1, NULL);
+			rnd_hid_cfg_keys_add_by_desc(&mctx->hc_keymap, n_keydesc, n_action);
+			accel = rnd_hid_cfg_keys_gen_accel(&mctx->hc_keymap, n_keydesc, 1, NULL);
 		}
 		else
 			rnd_hid_cfg_error(sub_res, "No action specified for key accel\n");
@@ -234,7 +233,7 @@ static mbtk_box_t *rnd_mbtk_menu_create_(rnd_mbtk_t *mctx, mbtk_widget_t *parent
 			if ((tip != NULL) || (n_keydesc != NULL)) {
 				char *acc = NULL, *s;
 				if (n_keydesc != NULL)
-					acc = rnd_hid_cfg_keys_gen_accel(&rnd_mbtk_keymap, n_keydesc, -1, "\nhotkey: ");
+					acc = rnd_hid_cfg_keys_gen_accel(&mctx->hc_keymap, n_keydesc, -1, "\nhotkey: ");
 				s = rnd_concat((tip == NULL ? "" : tip), "\nhotkey: ", (acc == NULL ? "" : acc), NULL);
 				gtk_widget_set_tooltip_text(row, s);
 				free(s);
@@ -346,7 +345,7 @@ int rnd_mbtk_load_menus(rnd_mbtk_t *mctx)
 	}
 
 	mr = rnd_hid_cfg_get_menu(rnd_gui->menu, "/mouse");
-	if (rnd_hid_cfg_mouse_init(rnd_gui->menu, &rnd_mbtk_mouse) != 0)
+	if (rnd_hid_cfg_mouse_init(rnd_gui->menu, &mctx->hc_mouse) != 0)
 		rnd_message(RND_MSG_ERROR, "Error: failed to load mouse actions from the hid config lihata - mouse input will not work.");
 
 	rnd_hid_menu_gui_ready_to_modify(rnd_gui);
