@@ -1,6 +1,7 @@
 #ifndef LIBRND_LIB_MBTK_COMMON_TOPWIN
 #define LIBRND_LIB_MBTK_COMMON_TOPWIN
 
+#include <librnd/core/conf_hid.h>
 #include <libmbtk/widget.h>
 
 struct rnd_mbtk_topwin_s {
@@ -21,8 +22,12 @@ struct rnd_mbtk_topwin_s {
 	mbtk_canvas_native_t drawing_area;
 	mbtk_scrollbar_t vscroll, hscroll;
 
+	/* bottom status bar and command prompt */
 	mbtk_box_t bottom_hbox;
-	mbtk_label_t cmd_prompt, cmd;
+	mbtk_label_t cmd_prompt;
+	mbtk_combo_t cmd;
+	unsigned cmd_finished:1;
+	const char *cmd_entered;
 
 	/* docking */
 	mbtk_box_t dockbox[RND_HID_DOCK_max];
