@@ -24,13 +24,13 @@ extern rnd_hid_t loghid_exp;
 	} \
 
 
-static const rnd_export_opt_t *log_get_export_options(rnd_hid_t *hid, int *ret)
+static const rnd_export_opt_t *log_get_export_options(rnd_hid_t *hid, int *ret, rnd_design_t *dsg, void *appspec)
 {
 	const rnd_export_opt_t *result;
 
 	SANITY(return NULL);
 
-	result = delegatee_->get_export_options(hid, ret);
+	result = delegatee_->get_export_options(hid, ret, dsg, appspec);
 	if (ret != NULL)
 		rnd_fprintf(out_, "get_export_options(ret) -> ret=%d\n", *ret);
 	else
@@ -45,11 +45,11 @@ static void log_do_exit(rnd_hid_t *hid)
 	delegatee_->do_exit(delegatee_);
 }
 
-static void log_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *opt)
+static void log_do_export(rnd_hid_t *hid, rnd_design_t *design, rnd_hid_attr_val_t *options, void *appspec)
 {
 	SANITY(return);
 	rnd_fprintf(out_, "do_export()\n");
-	delegatee_->do_export(delegatee_, opt);
+	delegatee_->do_export(delegatee_, design, options, appspec);
 }
 
 static int log_parse_arguments(rnd_hid_t *hid, int *argc, char ***argv)
@@ -87,11 +87,11 @@ static void log_notify_mark_change(rnd_hid_t *hid, rnd_bool changes_complete)
 	delegatee_->notify_mark_change(hid, changes_complete);
 }
 
-static int log_set_layer_group(rnd_hid_t *hid, rnd_layergrp_id_t group, const char *purpose, int purpi, rnd_layer_id_t layer, unsigned int flags, int is_empty, rnd_xform_t **xform)
+static int log_set_layer_group(rnd_hid_t *hid, rnd_design_t *design, rnd_layergrp_id_t group, const char *purpose, int purpi, rnd_layer_id_t layer, unsigned int flags, int is_empty, rnd_xform_t **xform)
 {
 	SANITY(return -1);
 	rnd_fprintf(out_, "set_layer(group=%ld, layer=%ld, flags=%lx, empty=%s, xform=%p)\n", group, layer, flags, is_empty ? "true" : "false", xform);
-	return delegatee_->set_layer_group(hid, group, purpose, purpi, layer, flags, is_empty, xform);
+	return delegatee_->set_layer_group(hid, design, group, purpose, purpi, layer, flags, is_empty, xform);
 }
 
 static void log_end_layer(rnd_hid_t *hid)
@@ -168,13 +168,6 @@ static void log_set_draw_xor(rnd_hid_gc_t gc, int xor)
 	delegatee_->set_draw_xor(gc, xor);
 }
 
-static void log_set_draw_faded(rnd_hid_gc_t gc, int faded)
-{
-	SANITY(return);
-	rnd_fprintf(out_, "set_draw_faded(gc, %s)\n", faded ? "true" : "false");
-	delegatee_->set_draw_faded(gc, faded);
-}
-
 static void log_draw_line(rnd_hid_gc_t gc, rnd_coord_t x1, rnd_coord_t y1, rnd_coord_t x2, rnd_coord_t y2)
 {
 	SANITY(return);
@@ -235,13 +228,6 @@ static void log_fill_rect(rnd_hid_gc_t gc, rnd_coord_t x1, rnd_coord_t y1, rnd_c
 	delegatee_->fill_rect(gc, x1, y1, x2, y2);
 }
 
-static void log_beep(rnd_hid_t *hid)
-{
-	SANITY(return);
-	rnd_fprintf(out_, "beep();   BEEEP   .... BEEEEEEEP\n");
-	delegatee_->beep(hid);
-}
-
 void create_log_hid(FILE *log_out, rnd_hid_t *loghid, rnd_hid_t *delegatee)
 {
 	out_ = log_out;
@@ -279,7 +265,6 @@ void create_log_hid(FILE *log_out, rnd_hid_t *loghid, rnd_hid_t *delegatee)
 	REGISTER_IF_NOT_NULL(set_line_cap);
 	REGISTER_IF_NOT_NULL(set_line_width);
 	REGISTER_IF_NOT_NULL(set_draw_xor);
-	REGISTER_IF_NOT_NULL(set_draw_faded);
 	REGISTER_IF_NOT_NULL(draw_line);
 	REGISTER_IF_NOT_NULL(draw_arc);
 	REGISTER_IF_NOT_NULL(draw_rect);
@@ -287,7 +272,6 @@ void create_log_hid(FILE *log_out, rnd_hid_t *loghid, rnd_hid_t *delegatee)
 	REGISTER_IF_NOT_NULL(fill_polygon);
 	REGISTER_IF_NOT_NULL(fill_polygon_offs);
 	REGISTER_IF_NOT_NULL(fill_rect);
-	REGISTER_IF_NOT_NULL(beep);
 
 #undef REGISTER_IF_NOT_NULL
 }
