@@ -19,7 +19,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *  Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA.
  *
  *  Contact:
  *    Project page: http://www.repo.hu/projects/librnd
@@ -154,6 +154,7 @@ static void script_free(script_t *s, const char *preunload, const char *cookie)
 #endif
 	free(s->id);
 	free(s->fn);
+	free(s->lang);
 	free(s);
 }
 
