@@ -32,7 +32,7 @@
  
        You should have received a copy of the GNU General Public
        License along with this program; if not, write to the Free
-       Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+       Software Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA.
  
       polygon1.c
       (C) 1997 Alexey Nikitin, Michael Leonov
