@@ -34,6 +34,7 @@
 #include "pa_label.c"
 #include "pa_collect_tmp.c"
 #include "pa_collect.c"
+#include "pa_dicer.c"
 
 #include "pa_api_bool.c"
 #include "pa_api_vertex.c"
@@ -45,3 +46,5 @@
 #include "pa_self_isc.c"
 
 #include "pa_compat.c"
+
+int rnd_polybool_assert_on_error_code = 0;
