@@ -15,7 +15,7 @@
 
       You should have received a copy of the GNU Library General Public
       License along with this library; if not, write to the Free
-      Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+      Software Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA.
 
       polyarea.h
       (C) 1997 Alexey Nikitin, Michael Leonov
