@@ -18,7 +18,7 @@
  *
  *  You should have received a copy of the GNU Lesser General Public
  *  License along with this library; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ *  Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA
  *
  *  Contact:
  *    Project page: http://www.repo.hu/projects/librnd
@@ -264,6 +264,7 @@ RND_INLINE void pb2_arc_bbox(pb2_seg_t *arc)
 {
 	g2d_carc_t carc;
 	g2d_box_t bb;
+	double end;
 
 	SEG2CARC(carc, arc);
 	bb = g2d_carc_bbox(&carc);
@@ -272,16 +273,21 @@ RND_INLINE void pb2_arc_bbox(pb2_seg_t *arc)
 	   that it has the point for angle 0 in between the start and stop angles.
 	   In any other setup either of the endpoints would be the rightmost point. */
 	if (carc.start < 0) carc.start += 2*G2D_PI;
-	else if (carc.start > 2*G2D_PI) carc.start -= 2*G2D_PI;
-	if (carc.delta > 0)
-		arc->shape.arc.right_curving = ((carc.start+carc.delta) > 2*G2D_PI);
+	else if (carc.start >= 2*G2D_PI) carc.start -= 2*G2D_PI;
+
+	end = carc.start+carc.delta;
+
+	if ((carc.start == 0) || (end == 0) || (end == 2*G2D_PI))
+		arc->shape.arc.right_curving = 0; /* 0 deg is and endpoint -> can't curve more to the right */
+	else if (carc.delta > 0)
+		arc->shape.arc.right_curving = (end > 2*G2D_PI); /* start is [0..2pi); end is above 2pi so we had to cross 2pi */
 	else if (carc.delta < 0)
-		arc->shape.arc.right_curving = ((carc.start+carc.delta) < 0);
+		arc->shape.arc.right_curving = (end < 0); /* start is [0..2pi); end is below 0 so we had to cross 0 */
 	else /* delta == 0 */
-		arc->shape.arc.right_curving = 0;
+		arc->shape.arc.right_curving = 0; /* we are not even curving at all */
 
 	arc->bbox.x1 = floor(bb.p1.x); arc->bbox.y1 = floor(bb.p1.y);
-	arc->bbox.x2 = ceil(bb.p2.x); arc->bbox.y2 = ceil(bb.p2.y);
+	arc->bbox.x2 = ceil(bb.p2.x)+1; arc->bbox.y2 = ceil(bb.p2.y)+1;
 }
 
 
@@ -368,7 +374,7 @@ RND_INLINE void pb2_arc_tangent_from(rnd_vector_t dst, pb2_seg_t *seg, rnd_vecto
 	rnd_vector_t spoke;
 	int inv;
 
-	/* radial direction */
+	/* radial direction, pointing out from the center */
 	spoke[0] = from[0] - seg->shape.arc.center[0];
 	spoke[1] = from[1] - seg->shape.arc.center[1];
 
@@ -390,28 +396,56 @@ RND_INLINE void pb2_arc_tangent_from(rnd_vector_t dst, pb2_seg_t *seg, rnd_vecto
 	}
 }
 
+
+/* same but with precise coords (real center of the arc, using doubles) */
+RND_INLINE void pb2_arc_tangent_from_dbl(double dst[], double spoke[], pb2_seg_t *seg, rnd_vector_t from)
+{
+	int inv;
+
+	/* radial direction, pointing out from the center */
+	spoke[0] = (double)from[0] - seg->shape.arc.cx;
+	spoke[1] = (double)from[1] - seg->shape.arc.cy;
+
+	/* inverse direction on CCW */
+	inv = (seg->shape.arc.adir == 0);
+
+	/* inverse direction when computing for endpoint */
+	if (Vequ2(from, seg->end))
+		inv = !inv;
+
+	/* normal vector of radial direction */
+	if (inv) {
+		dst[0] = +spoke[1];
+		dst[1] = -spoke[0];
+	}
+	else {
+		dst[0] = -spoke[1];
+		dst[1] = spoke[0];
+	}
+}
+
+
 /* Return tangential "angle" at endpoint "from" */
 RND_INLINE void pb2_arc_angles_from(pa_angle_t *dst1, pa_angle_t *dst2, pb2_seg_t *seg, rnd_vector_t from)
 {
-	rnd_vector_t norm, tang, radial, between;
+	double norm[2], radial[2], between[2];
 
-	pb2_arc_tangent_from(norm, seg, from);
-
-	tang[0] = from[0] + norm[0];
-	tang[1] = from[1] + norm[1];
+	pb2_arc_tangent_from_dbl(norm, radial, seg, from);
 
 	/* first angle is tangential */
-	pa_calc_angle_nn(dst1, from, tang);
+	pa_calc_angle_n0_dbl(dst1, norm);
 
-	/* second angle is something in between tangential and radial, always pointing inside the arc area */
-	radial[0] = from[0] - seg->shape.arc.center[0];
-	radial[1] = from[1] - seg->shape.arc.center[1];
-	between[0] = (radial[0] + tang[0])/2;
-	between[1] = (radial[1] + tang[1])/2;
-	pa_calc_angle_nn(dst2, from, between);
+	/* Second angle is something in between tangential and radial, always
+	   pointing inside the arc area. Have to invert radial because it's
+	   pointing out from the center. These two vectors are not normalized
+	   but are of the same magnitude so it's safe to average them */
+	between[0] = (-radial[0] + norm[0])/2;
+	between[1] = (-radial[1] + norm[1])/2;
+	pa_calc_angle_n0_dbl(dst2, between);
 }
 
 
+
 RND_INLINE pb2_slope_t pb2_slope_arc(pb2_seg_t *seg, rnd_vector_t from)
 {
 	pb2_slope_t slp;
@@ -762,3 +796,27 @@ void pb2_raw_tangent_from_arc(rnd_vector_t dst, rnd_vector_t ap1, rnd_vector_t a
 
 	pb2_arc_tangent_from(dst, &aseg, from);
 }
+
+int pb2_iscp_cline_cline_o(rnd_vector_t l1a, rnd_vector_t l1b, rnd_vector_t l2a, rnd_vector_t l2b, rnd_vector_t ipo[2], double offs[2], int always_offs)
+{
+	g2d_cline_t c1, c2;
+	g2d_cvect_t ip[2];
+	int ni;
+
+	c1.p1.x = l1a[0]; c1.p1.y = l1a[1];
+	c1.p2.x = l1b[0]; c1.p2.y = l1b[1];
+	c2.p1.x = l2a[0]; c2.p1.y = l2a[1];
+	c2.p2.x = l2b[0]; c2.p2.y = l2b[1];
+	ni = g2d__iscp_cline_cline_o(&c1, &c2, ip, offs, always_offs);
+
+	if (ni > 0) {
+		ipo[0][0] = rnd_round(ip[0].x);
+		ipo[0][1] = rnd_round(ip[0].y);
+	}
+	if (ni > 1) {
+		ipo[1][0] = rnd_round(ip[1].x);
+		ipo[1][1] = rnd_round(ip[1].y);
+	}
+
+	return ni;
+}
