@@ -47,7 +47,9 @@ typedef enum rnd_poly_fct_e { /* bitfield */
 } rnd_poly_fct_t;
 
 /* Draw a fractional-circle from start to end (assuming start and end
-   are added by the caller). Start and end must be on the same radius from cx;cy */
+   are added by the caller; this effectively replaces an existing straight
+   line segment with a real or approximated arc). Start and end must be on
+   the same radius from cx;cy */
 void rnd_poly_frac_circle_to(rnd_pline_t *c, rnd_vnode_t *insert_at, rnd_coord_t cx, rnd_coord_t cy, const rnd_vector_t start, const rnd_vector_t end, rnd_poly_fct_t how);
 
 
