@@ -6,7 +6,7 @@
 
 static void rnd_hook_detect_cc(void)
 {
-	int need_inl = 0;
+	int need_inl = 0, c89_std_appended = 0;
 	const char *host_ansi, *host_ped, *target_ansi, *target_ped, *target_pg, *target_no_pie;
 	const char *tmp, *fpic, *debug;
 
@@ -18,6 +18,7 @@ static void rnd_hook_detect_cc(void)
 	target_pg = get("/target/cc/argstd/pg");
 	target_no_pie = get("/target/cc/argstd/no-pie");
 	require("cc/pragma_message",  0, 0);
+	require("cc/disable_c23/cflags",  0, 1);
 	require("fstools/ar",  0, 1);
 	require("fstools/ranlib",  0, 0);
 
@@ -35,6 +36,7 @@ static void rnd_hook_detect_cc(void)
 		if (target_ansi != NULL) {
 			append("/target/cc/cflags", " ");
 			append("/target/cc/cflags", target_ansi);
+			c89_std_appended = 1;
 		}
 		if (target_ped != NULL) {
 			append("/target/cc/cflags", " ");
@@ -51,7 +53,7 @@ static void rnd_hook_detect_cc(void)
 	/* set cflags for C89 */
 	put("/local/" APP "/c89flags", "");
 	if (istrue(get("/local/" APP "/debug"))) {
-
+		c89_std_appended = 1;
 		if ((target_ansi != NULL) && (*target_ansi != '\0')) {
 			append("/local/" APP "/c89flags", " ");
 			append("/local/" APP "/c89flags", target_ansi);
@@ -64,6 +66,15 @@ static void rnd_hook_detect_cc(void)
 		}
 	}
 
+	/* set cflags for C99 - have to disable C23 because it is incompatible */
+	put("/local/" APP "/c99flags", "");
+	tmp = get("cc/disable_c23/cflags");
+	if ((tmp != NULL) && (*tmp != '\0')) {
+		append("/local/" APP "/c99flags", tmp);
+		if (!c89_std_appended)
+			append("/local/" APP "/c89flags", tmp);
+	}
+
 	if (istrue(get("/local/" APP "/profile"))) {
 		append("/local/" APP "/cflags_profile", " ");
 		append("/local/" APP "/cflags_profile", target_pg);
