@@ -16,7 +16,7 @@
 
     You should have received a copy of the GNU Library General Public
     License along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+    Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA
 
     Project page: http://repo.hu/projects/libporty
     Author: libporty@igor2.repo.hu
@@ -302,7 +302,7 @@ P_net_socket P_socket(int af, int protocol, int type)
 
     You should have received a copy of the GNU Library General Public
     License along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+    Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA
 
     Project page: http://repo.hu/projects/libporty
     Author: libporty@igor2.repo.hu
@@ -409,7 +409,7 @@ void P_dsleep(double secs)
 
     You should have received a copy of the GNU Library General Public
     License along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+    Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA
 
     Project page: http://repo.hu/projects/libporty
     Author: libporty@igor2.repo.hu
@@ -606,7 +606,7 @@ int P_tcp4_accept(P_net_socket *new_socket, P_net_socket listen_sock, P_ipv4_add
 
     You should have received a copy of the GNU Library General Public
     License along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+    Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA
 
     Project page: http://repo.hu/projects/libporty
     Author: libporty@igor2.repo.hu
@@ -838,7 +838,7 @@ int P_dns4_addr_to_IP(P_ipv4_addr_t *ip_out, const char *addr_in)
 
     You should have received a copy of the GNU Library General Public
     License along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+    Foundation, Inc., 31 Milk Street, # 960789 Boston, MA 02196 USA
 
     Project page: http://repo.hu/projects/libporty
     Author: libporty@igor2.repo.hu
